      PROGRAM SOFA EARTH ORIENTATION EXAMPLES
*
* Demonstration program of SOFA Routines for Earth Orientation
*
* Example 1 GCRS -> CIRS using SOFA Routines (C2I)
*
* Catherine Hohenkerk
* Chair, IAU SOFA Board
* 2013 September 15
*
      IMPLICIT NONE
      INTEGER          IY, IM, ID, IHR, IMN, J
      DOUBLE PRECISION SEC, TT1, TT2, C(3,3)

*  Arc seconds to radians
      DOUBLE PRECISION DAS2R
      PARAMETER      ( DAS2R = 4.848136811095359935899141D-6 )

* User parameters for Examples 1, 2 and 3
* Civil date, TT
      IY = 2013
      IM = 9
      ID = 15
      IHR = 17
      IMN = 30
      SEC = 0D0

      CALL iau_DTF2D ( 'TT', IY, IM, ID, IHR, IMN, SEC, TT1, TT2, J )

* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

* Example 1: SOFA Demonstration routine for the Journees 2013 Workshop
*
*  Form the celestial-to-intermediate matrix for a given date using the
*  IAU 2006 precession and IAU 2000A nutation models.
*
      CALL iau_C2I06A ( TT1, TT2, C )

* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

* Print results.
* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      WRITE (6, 935)
      WRITE (6, '(A)')'2013 Journees Workshop, Earth Orientation using I
     :AU SOFA Routines'
      WRITE (6, 935)
      WRITE (6, *)

* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

      WRITE (6, 935)
      WRITE (6, '(A)') 'Example 1: GCRS -> CIRS, using SOFA Routines'
      WRITE (6, 935)
      WRITE (6, 950) 'Date and time (TT)', IY, IM, ID, IHR, IMN, SEC
      WRITE (6, 930) 'JD (TT) = TT1 + TT2 ', TT1, TT2, TT1+TT2
      CALL PMAT ( 'GCRS TO CIRS matrix using iau_C2I06A', C )
      WRITE (6, 935)
      WRITE (6, 935)
      WRITE (6, '(A)')'Produced by Catherine Hohenkerk, Chair, IAU SOFA
     :Board, 2013 September'
      WRITE (6, 935)

* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

 930  FORMAT(/ 2X, A, '=',F10.1,' + ' F12.10, ' = ', F18.10)
 935  FORMAT('+ ',33('- '), '-+')
 945  FORMAT( 2X, '     DX (") = ', F13.9, 3X,'DY (") = ' F13.9)
 950  FORMAT(/A, 1X, I4,3(1X,I2.2),':',I2.2,':',F5.2)

*+----------------------------------------------------------------------

      END

      SUBROUTINE PMAT ( TEXT, R )

* Print the matrix R

      IMPLICIT NONE
      DOUBLE PRECISION R(3,3)
      INTEGER          I, J
      CHARACTER        TEXT*(*)

      WRITE (6,'(/A)') TEXT
      DO I = 1,3
       WRITE (6, 950) (R(I,J),J=1,3)
 950   FORMAT( 4X, 3F20.15)
      ENDDO

      END

